@@ -46,66 +46,35 @@
 #'    resample-experiment, regarding the given measure, then assign its
 #'    feature subset and aggregated performance to the instance.
 #'
+#' @template param_man
+#'
 #' @export
-#' @examples
-#' library(mlr3)
-#'
-#' terminator = trm("evals", n_evals = 3)
-#'
-#' instance = FSelectInstanceSingleCrit$new(
-#'   task = tsk("iris"),
-#'   learner = lrn("classif.rpart"),
-#'   resampling = rsmp("holdout"),
-#'   measure = msr("classif.ce"),
-#'   terminator = terminator
-#' )
-#'
-#' # swap this line to use a different FSelector
-#' fselector = fs("random_search")
-#' \donttest{
-#' # modifies the instance by reference
-#' fselector$optimize(instance)
-#'
-#' # returns best feature subset and best performance
-#' instance$result
-#'
-#' # allows access of data.table / benchmark result of full path of all evaluations
-#' instance$archive}
 FSelector = R6Class("FSelector",
   public = list(
 
-    #' @field param_set ([paradox::ParamSet]).
-    param_set = NULL,
-
-    #' @field param_classes (`character()`).
-    param_classes = NULL,
-
-    #' @field properties (`character()`).
-    properties = NULL,
-
-    #' @field packages (`character()`).
-    packages = NULL,
-
     #' @description
-    #' Creates a new instance of this [R6][R6::R6Class] class.
+    #'   Creates a new instance of this [R6][R6::R6Class] class.
     #'
     #' @param param_set [paradox::ParamSet]\cr
-    #' Set of control parameters for fselector.
+    #'   Set of control parameters.
     #'
     #' @param properties (`character()`)\cr
-    #' Set of properties of the fselector. Must be a subset of
-    #' [`mlr_reflections$fselect_properties`][mlr3::mlr_reflections].
+    #'   Set of properties of the fselector.
+    #'   Must be a subset of [`mlr_reflections$fselect_properties`][mlr3::mlr_reflections].
     #'
     #' @param packages (`character()`)\cr
-    #' Set of required packages. Note that these packages will be loaded via
-    #' [requireNamespace()], and are not attached.
-    initialize = function(param_set, properties, packages = character()) {
-      self$param_set = assert_param_set(param_set)
-      self$param_classes = "ParamLgl"
-      self$properties = assert_subset(properties,
-        bbotk_reflections$optimizer_properties,
-        empty.ok = FALSE)
-      self$packages = union("mlr3fselect", assert_character(packages, any.missing = FALSE, min.chars = 1L))
+    #'   Set of required packages.
+    #'   Note that these packages will be loaded via [requireNamespace()], and are not attached.
+    #'
+    #' @param label (`character(1)`)\cr
+    #'   Label for this object.
+    #'   Can be used in tables, plot and text output instead of the ID.
+    initialize = function(param_set, properties, packages = character(), label = NA_character_, man = NA_character_) {
+      private$.param_set = assert_param_set(param_set)
+      private$.properties = assert_subset(properties, bbotk_reflections$optimizer_properties, empty.ok = FALSE)
+      private$.packages = union("mlr3fselect", assert_character(packages, any.missing = FALSE, min.chars = 1L))
+      private$.label = assert_string(label, na.ok = TRUE)
+      private$.man = assert_string(man, na.ok = TRUE)
 
       check_packages_installed(self$packages, msg = sprintf("Package '%%s' required but not installed for FSelector '%s'", format(self)))
     },
@@ -121,13 +90,19 @@ FSelector = R6Class("FSelector",
     #' Print method.
     #' @return (`character()`).
     print = function() {
-      catf(format(self))
+      catn(format(self), if (is.na(self$label)) "" else paste0(": ", self$label))
       catf(str_indent("* Parameters:", as_short_string(self$param_set$values)))
-      catf(str_indent("* Parameter classes:", self$param_classes))
       catf(str_indent("* Properties:", self$properties))
       catf(str_indent("* Packages:", self$packages))
     },
 
+
+    #' @description
+    #' Opens the corresponding help page referenced by field `$man`.
+    help = function() {
+      open_help(self$man)
+    },
+
     #' @description
     #' Performs the feature selection on a [FSelectInstanceSingleCrit] or
     #' [FSelectInstanceMultiCrit] until termination.
@@ -144,12 +119,71 @@ FSelector = R6Class("FSelector",
     }
   ),
 
+  active = list(
+
+    #' @field param_set [paradox::ParamSet]\cr
+    #'   Set of control parameters.
+    param_set = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.param_set)) {
+        stop("$param_set is read-only.")
+      }
+      private$.param_set
+    },
+
+    #' @field properties (`character()`)\cr
+    #'   Set of properties of the fselector.
+    #'   Must be a subset of [`mlr_reflections$fselect_properties`][mlr3::mlr_reflections].
+    properties = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.properties)) {
+        stop("$properties is read-only.")
+      }
+      private$.properties
+    },
+
+    #' @field packages (`character()`)\cr
+    #'   Set of required packages.
+    #'   Note that these packages will be loaded via [requireNamespace()], and are not attached.
+    packages = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.packages)) {
+        stop("$packages is read-only.")
+      }
+      private$.packages
+    },
+
+    #' @field label (`character(1)`)\cr
+    #'   Label for this object.
+    #'   Can be used in tables, plot and text output instead of the ID.
+    label = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.param_set)) {
+        stop("$label is read-only.")
+      }
+      private$.label
+    },
+
+    #' @field man (`character(1)`)\cr
+    #'   String in the format `[pkg]::[topic]` pointing to a manual page for this object.
+    #'   The referenced help package can be opened via method `$help()`.
+    man = function(rhs) {
+      if (!missing(rhs) && !identical(rhs, private$.man)) {
+        stop("$man is read-only.")
+      }
+      private$.man
+    }
+  ),
+
   private = list(
     .optimize = function(inst) stop("abstract"),
 
     .assign_result = function(inst) {
       assert_multi_class(inst, c("FSelectInstanceSingleCrit", "FSelectInstanceMultiCrit"))
       assign_result_default(inst)
-    }
+    },
+
+    .param_set = NULL,
+    .param_classes = "ParamLgl", # keeps compatibility to bbotk
+    .properties = NULL,
+    .packages = NULL,
+    .label = NULL,
+    .man = NULL
   )
 )
